<p align="center">
    <a href="https://github.com/OctoDiary">
        <img src="https://avatars.githubusercontent.com/u/90847608?s=200&v=4" alt="OctoDiary" width="200">
    </a>
    <br>
    <a href="https://t.me/OctoDiary"><b>Telegram-Канал</b></a>
    •
    <a href="https://pypi.org/project/octodiary/"><b>PyPI</b></a>
    <br>
    <br>
    <a href="https://opensource.org/licenses/MIT"><image src="https://img.shields.io/badge/License-MIT-blue.svg" alt="MIT License"></a>
    <a href="https://www.python.org/"><image src="https://img.shields.io/badge/python-3.9%20%7C%203.10%20%7C%203.11-blue.svg" alt="Python Version"></a>
    <a href="https://pypi.org/project/octodiary/"><image src="https://img.shields.io/pypi/v/octodiary.svg" alt="PyPI Version"></a>
</p>


# OctoDiary-py
Неофициальная Python-библиотека для использования API МЭШ / Моя Школа.

## Установка

### Новейшая версия:
``` bash
$ pip install https://github.com/OctoDiary/OctoDiary-py/archive/main.zip --upgrade
```

### Стабильная версия:
``` bash
$ pip install octodiary --upgrade
```

## Использование
Смотрите [Examples.md](Examples.md)

## Ссылки
- [**PyPI**](https://pypi.org/project/octodiary/)
- [**Другие проекты**](https://github.com/OctoDiary)
- [**Telegram-канал**](https://t.me/OctoDiary)
